/*
 * Created on 02-Dec-2005
 * Created by Paul Gardner
 * Copyright (C) 2005, 2006 Aelitis, All Rights Reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * 
 * AELITIS, SAS au capital de 40,000 euros
 * 8 Allee Lenotre, La Grille Royale, 78600 Le Mesnil le Roi, France.
 *
 */

package com.aelitis.azureus.core.diskmanager.access;

import com.aelitis.azureus.core.diskmanager.access.impl.DiskAccessControllerImpl;

public class 
DiskAccessControllerFactory 
{
	public static DiskAccessController
	create(
		String		name,
		int			max_read_threads,
		int			max_read_mb,
		int 		max_write_threads,
		int			max_write_mb )
	{
		return( new DiskAccessControllerImpl(
						name,
						max_read_threads,  max_read_mb,
						max_write_threads, max_write_mb ));
	}
}
